#ifndef __ctibh_h
#define __ctibh_h
/************************************************************
(C) Copyright 2006
Connect Tech Inc.
All rights reserved.
************************************************************/

#include <ansidecl_lynx.h>  /* _AP wrapper for ANSI prototypes */

#ifdef __cplusplus
extern "C" {
#endif


#if !defined(__CTIBH_ADDR_MUL__)
/*
* Some powerpc BSP's map the tty ports to registers which means the offsets
* below are no longer valid.  So, we have to multiply the offset by the
* appropriate constant (based on the size of the registers they are mapped to)
* to get the correct port address.  If a particular bsp does this it
* will define __CTIBH_ADDR_MUL__ as well as __ctibh_is_skdb_port() and
* __ctibh_uart_location().
*/
#define __CTIBH_ADDR_MUL__           1
#define __ctibh_is_skdb_port(port)   ((port) == (int)skdb_port_serial)
#define __ctibh_uart_location(uart)  (uart)

/*
* sample #defines for 32 bit registers
*
* #define __CTIBH_ADDR_MUL__           4
* #define __ctibh_is_skdb_port(port)   ((((port) / __CTIBH_ADDR_MUL__) & 0x3ff)
*                                          == ((int)skdb_port_serial & 0x3ff))
* #define __ctibh_uart_location(uart)  (((uart) & 0xfffff000)
*                                          | (((uart) & 0x3ff) * __CTIBH_ADDR_MUL__))
*/
#endif  /* __CTIBH_ADDR_MUL__ */

/*#define debug(_args_) kkprintf _args_*/
/*#define isr_debug(_args_) kkprintf _args_*/
#define debug(_args_)
#define isr_debug(_args_)

#define V3_VENDORID       0x11b0
#define CTIBH_VENDORID    0x12c4
#define BH_STATUS_OFFSET  0x4c

#define PCI_IO_ENABLE         0x1
#define PCI_MEM_ENABLE        0x2
#define PCI_BUSMASTER_ENABLE  0x4

/*
* UART port assignments
*/
#define U_RBR  (0x00 * __CTIBH_ADDR_MUL__)  /* RD: receive buffer (LCR_DLAB=0) */
#define U_THR  (0x00 * __CTIBH_ADDR_MUL__)  /* WR: transmit buffer (LCR_DLAB=0) */
#define U_DLL  (0x00 * __CTIBH_ADDR_MUL__)  /* WR: divisor latch LSB (LCR_DLAB=1) */
#define U_DLM  (0x01 * __CTIBH_ADDR_MUL__)  /* WR: divisor latch MSB (LCR_DLAB=1) */
#define U_IER  (0x01 * __CTIBH_ADDR_MUL__)  /* WR: interrupt enable register */
#define U_IIR  (0x02 * __CTIBH_ADDR_MUL__)  /* RD: interrupt ident. register */
#define U_FCR  (0x02 * __CTIBH_ADDR_MUL__)  /* WR: FIFO control register (16550) */
#define U_LCR  (0x03 * __CTIBH_ADDR_MUL__)  /* WR: line control register */
#define U_MCR  (0x04 * __CTIBH_ADDR_MUL__)  /* WR: modem control register */
#define U_LSR  (0x05 * __CTIBH_ADDR_MUL__)  /* RD: line status register */
#define U_MSR  (0x06 * __CTIBH_ADDR_MUL__)  /* RD: modem status register */
#define U_EFR  (0x02 * __CTIBH_ADDR_MUL__)  /* RDWR: enhanced feature register */

/*
* interrupt enable register (read/write)
*/
#define IER_RDA  0x01  /* received data available */
#define IER_TRE  0x02  /* transmit register empty */
#define IER_RLS  0x04  /* receiver line status */
#define IER_MS   0x08  /* modem status */

/*
* interrupt ident register (read only)
*/
#define IIR_PEN   0x01  /* 0 if interrupt pending */
#define IIR_IID   0x0e  /* 3 bit interrupt ID (bit 0x80 on 16550 only) */
#define IIR_RLS   0x06  /* pri=1: receiver line status */
#define IIR_RDA   0x04  /* pri=2: received data available */
#define IIR_CTI   0x0c  /* pri=2: fifo char. timeout ind. (16550) */
#define IIR_TRE   0x02  /* pri=3: transmit register empty */
#define IIR_MS    0x00  /* pri=4: modem status */
#define IIR_FIFO  0xc0  /* both bits set when fifos enabled (16550) */

/*
* fifo control register (write only)
*/
#define FCR_EN     0x01  /* FIFO enable */
#define FCR_RFR    0x02  /* RCVR FIFO reset */
#define FCR_TFR    0x04  /* XMIT FIFO reset */
#define FCR_DMS    0x04  /* DMA mode select */
#define FCR_TTLS   0x30  /* TMTR trigger level select */
#define FCR_TTL8   0x00  /* TMTR trigger level 1 byte */
#define FCR_TTL16  0x10  /* TMTR trigger level 4 bytes */
#define FCR_TTL32  0x20  /* TMTR trigger level 8 bytes */
#define FCR_TTL56  0x30  /* TMTR trigger level 14 bytes */
#define FCR_RTLS   0xc0  /* RCVR trigger level select */
#define FCR_RTL8   0x00  /* RCVR trigger level 1 byte */
#define FCR_RTL16  0x40  /* RCVR trigger level 4 bytes */
#define FCR_RTL56  0x80  /* RCVR trigger level 8 bytes */
#define FCR_RTL60  0xc0  /* RCVR trigger level 14 bytes */

/*
* line control register (read/write)
*/
#define LCR_WLS    0x03  /* word length select */
#define LCR_WL5    0x00  /* word length 5 bits */
#define LCR_WL6    0x01  /* word length 6 bits */
#define LCR_WL7    0x02  /* word length 7 bits */
#define LCR_WL8    0x03  /* word length 8 bits */
#define LCR_STB_1  0x00  /* 1 stop bits */
#define LCR_STB_2  0x04  /* 2 stop bits */
#define LCR_PEN    0x08  /* parity enable */
#define LCR_EPS    0x10  /* even parity select */
#define LCR_SP     0x20  /* stick parity */
#define LCR_BRK    0x40  /* set break */
#define LCR_DLAB   0x80  /* divisor latch access bit */

/*
* modem control register (read/write)
*/
#define MCR_DTR   0x01  /* data terminal ready */
#define MCR_RTS   0x02  /* request to send */
#define MCR_OT1   0x04  /* output 1 */
#define MCR_OT2   0x08  /* output 2 */
#define MCR_LOOP  0x10  /* loop mode */

/*
* line status register (read/write)
*/
#define LSR_DR   0x01  /* data ready */
#define LSR_OE   0x02  /* overrun error */
#define LSR_PE   0x04  /* parity error */
#define LSR_FE   0x08  /* framing error */
#define LSR_BI   0x10  /* break interrupt */
#define LSR_TRE  0x20  /* transmit register empty */
#define LSR_TSE  0x40  /* transmit shift register empty */

/*
* modem status register (read/write)
*/
#define MSR_DCTS  0x01  /* delta 0 clear to send */
#define MSR_DDSR  0x02  /* delta 0 data set ready */
#define MSR_TERI  0x04  /* trailing edge ring indicator */
#define MSR_DDCD  0x08  /* delta 0 data carrier detect */
#define MSR_CTS   0x10  /* clear to send */
#define MSR_DSR   0x20  /* data set ready */
#define MSR_RI    0x40  /* ring indicator */
#define MSR_DCD   0x80  /* data carrier detect */

/*
* enhanced feature register (read/write)
*/
#define EFR_SWFC0  0x01  /* software flow control bit 0 */
#define EFR_SWFC1  0x02  /* software flow control bit 1 */
#define EFR_SWFC2  0x04  /* software flow control bit 2 */
#define EFR_SWFC3  0x08  /* software flow control bit 3 */
#define EFR_EFB    0x10  /* enhanced function bits enable*/
#define EFR_SCD    0x20  /* special character detect */
#define EFR_ARTS   0x40  /* auto RTS# enable */
#define EFR_ACTS   0x80  /* auto CTS# enable */


#ifdef __cplusplus
}
#endif

#endif  /* __ctibh_h */
