#!/bin/sh

#
# Connect Tech's Blue Heat Dynamic Load script
#

version="1.0"

this=`basename $0`

num_devs=1

# Print the version string
print_version() {
  echo "$this v$version"
}

# Process the command line
case "$1" in
  -h)
    print_version
    echo
    echo "$this num"
    echo "$this -h"
    echo "$this -v"
    echo
    echo "-h	This help screen"
    echo "-v	Print the version string"
    echo "num	The number of Blue Heat boards to install"
    exit 0
    ;;
  -v)
    print_version
    exit 0
    ;;
  [0-9]*)
    num_devs=$1
    ;;
  *)
    if [ -z "$1" ]; then
      echo "$this: Error: Missing number of boards to install"
    else
      echo "$this: Error: Bad argument '$1'"
    fi
    exit 1
    ;;
esac

old_pwd=`pwd`

cd /sys/drivers/ctibh

# Make the driver
make ctibh

# Make the dynamic device helper
make ctibh_devinfo

# Unload all the old devices
line=`devices | grep ctibh_devinfo`
while [ ! -z "$line" ]; do
    num=`echo $line | cut -d" " -f1`
    devinstall -u -c $num
    line=`devices | grep ctibh_devinfo`
done

# Unload the old driver
line=`drivers | grep ctibh.obj`
if [ ! -z "$line" ]; then
    num=`echo $line | cut -d" " -f1`
    drinstall -u $num
fi

# Load the new driver
num=`drinstall -c ctibh.obj | cut -d" " -f2`

# Load the new devices
while [ $num_devs -gt 0 ]; do
    devinstall -c -d $num ctibh_devinfo
    num_devs=`expr $num_devs - 1`
done

cd $old_pwd
