#!/bin/sh

#
# Connect Tech's Blue Heat mknod script
#

version="1.0"

this=`basename $0`

# Print the version string
print_version() {
  echo "$this v$version"
}

# Process the command line
case "$1" in
  -h)
    print_version
    echo
    echo "$this id,ports [id,ports...]"
    echo "$this -h"
    echo "$this -v"
    echo
    echo "-h	This help screen"
    echo "-v	Print the version string"
    echo "id	The device id of an installed Blue Heat board"
    echo "ports	The number of ports on the board"
    echo
    echo "When a Blue Heat board is installed some information is printed out,"
    echo "like the number of ports. The driver does not know what device id"
    echo "will be assigned however. The id,ports pairs must be constructed by"
    echo "associating the number of ports, reported by the driver, with the"
    echo "appropriate device id, reported by devinstall. The driver"
    echo "information may be found in the system log."
    exit 0
    ;;
  -v)
    print_version
    exit 0
    ;;
esac

# Remove the old nodes
rm -f /dev/cbh*

# Make the new nodes
if [ ! -z "$1" ]; then
  old_umask="0`umask`"
  umask 0000

  board=0

  while [ ! -z "$1" ]; do
    case "$1" in
      [1-9][0-9]*,[248])
        dev_id=`echo $1 | cut -d, -f1`
        num_ports=`echo $1 | cut -d, -f2`
        port=0
        while [ $port -lt $num_ports ]; do
          mknod /dev/cbh$board.$port c $dev_id $port
          port=`expr $port + 1`
        done
        board=`expr $board + 1`
        ;;
      *)
        echo "$this: Error: Bad argument '$1'"
        ;;
    esac
    shift
  done

  umask $old_umask
fi
